==> haskell-rank2classes-1.5.4-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-FNtKPlgKrL25CocCA43DH2
key:                  rank2classes-1.5.4-FNtKPlgKrL25CocCA43DH2
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  9183605324e771029ee4ec7c749649de
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-FNtKPlgKrL25CocCA43DH2
depends:
    base-4.17.2.1 data-functor-logistic-0.0-K5LqRp5Rbgt9T3933jGOyK
    distributive-0.6.2.1-D63PkvKmNOQ513v5xoACY0
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rank2classes-1.5.4-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-DMl33FCQ49jGsgO9c7bZ9t
key:                  rank2classes-1.5.4-DMl33FCQ49jGsgO9c7bZ9t
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  213cb024a7a7c1631bfb513aecabd76c
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-DMl33FCQ49jGsgO9c7bZ9t
depends:
    base-4.17.2.1 data-functor-logistic-0.0-21Qx4dzEsQxFe6D4Q1Eg3L
    distributive-0.6.2.1-3pp9fAdpywz61tusPhXfY2
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
